@@ -1,8 +1,8 @@
 import random
-
 import re
+import string
 import typing
-from random import shuffle
+from random import sample
 from typing import Optional
 
 
@@ -46,16 +46,6 @@ def find_all(substring, full_string):
     return [m.start() for m in re.finditer(substring, full_string)]
 
 
-def shuffle_flags_for_commands(command):
-    parts = command.split('/')
-    new_command = parts.pop(0)
-    shuffle(parts)
-    for item in parts:
-        new_command += f' /{item}'
-    return new_command
+def get_random_string(length=10, charset=string.ascii_lowercase):
+    return ''.join(sample(population=charset, k=length))
 
-
-def random_choice_string(lst: [str]):
-    if lst is None or len(lst) is 0:
-        return ''
-    return random.choice(lst)
